---
title: Welcome to FragmentColor!
description: Your future guide to the easiest way to create cross-platform shaders.
---

import { Aside } from "@astrojs/starlight/components";

**FragmentColor** is a cross-platform GPU programming library
for **Rust**, **JavaScript**, **Python**, **Swift**, and **Kotlin**.

It directly targets each platform's native graphics API: 
**Vulkan**, **Metal**, **DirectX**, **OpenGL**, **WebGL**, or **WebGPU**.

See [Platform Support](/welcome/platforms) for details.

The API encourages a simple shader composition workflow. You can use **WGSL** or **GLSL** shaders
as the source of truth for visual consistency across platforms, while avoiding
the boilerplate needed to make modern GPU rendering work.

Check the [Documentation](/welcome) and the [API Reference](/api) for more information.

Follow the project on [GitHub](https://github.com/vista-art/fragmentcolor) to stay tuned on the latest updates.

## Example

import Examples from "../../../components/Examples.mdx";

<Examples />
